package apfel.test;
import org.omg.CORBA.ORB;

import apfel.calc.*;

import junit.framework.TestCase;

/**
 * @author  kurm
 */
public class ApfelTest extends TestCase {
  
  public ORB _orb;
  
  public static String[] _args;
  
  ApfelCalculatorFactory _factory = null;

  double x0 = -0.53262, y0 = 0.6121, unit = .000001220703125;  
  int width = 400, heigth = 400, iterations = 8000;

  public static void main(String[] args) {
    _args = args;
    junit.textui.TestRunner.run(ApfelTest.class);
  }

  public ApfelTest(String name) {
    super(name);
  }
  
  protected void setUp() throws Exception {
    super.setUp();

    _orb = ORB.init(_args, null);
    _factory = new ApfelCalculatorFactory(_orb);
  }
  
  protected void tearDown() throws Exception {
    super.tearDown();
  }

  /** 
   * Test CORBA synch calls 
   */
  public void test1() throws Exception {
    ApfelCalculator local = _factory.create(ApfelCalculatorFactory.MODE_LOCAL);
    ApfelCalculator other = _factory.create(ApfelCalculatorFactory.MODE_SYNCH);
    assertNotNull(other);
    
    int[][] arrLocal = local.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    int[][] arrOther = other.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    
    for (int i=0; i < width; i++)
      for (int j=0; j < heigth; j++)
        assertEquals(arrLocal[i][j],arrOther[i][j]);
  }

  /** 
   * Test CORBA ssynch calls 
   */
  public void test2() throws Exception {
    ApfelCalculator local = _factory.create(ApfelCalculatorFactory.MODE_LOCAL);
    ApfelCalculator other = _factory.create(ApfelCalculatorFactory.MODE_ASYNCH);
    assertNotNull(other);
    
    int[][] arrLocal = local.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    int[][] arrOther = other.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    
    for (int i=0; i < width; i++)
      for (int j=0; j < heigth; j++)
        assertEquals(arrLocal[i][j],arrOther[i][j]);
  }

  /** 
   * Test CORBA ami calls 
   */
  public void test3() throws Exception {
    ApfelCalculator local = _factory.create(ApfelCalculatorFactory.MODE_LOCAL);
    ApfelCalculator other = _factory.create(ApfelCalculatorFactory.MODE_AMI);
    assertNotNull(other);
    
    int[][] arrLocal = local.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    int[][] arrOther = other.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    
    for (int i=0; i < width; i++)
      for (int j=0; j < heigth; j++)
        assertEquals(arrLocal[i][j],arrOther[i][j]);
  }

  /** 
   * Test CORBA asynch calls with dsi
   */
  public void test4() throws Exception {
    ApfelCalculator local = _factory.create(ApfelCalculatorFactory.MODE_LOCAL);
    ApfelCalculator other = _factory.create(ApfelCalculatorFactory.MODE_DSI);
    assertNotNull(other);
    
    int[][] arrLocal = local.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    int[][] arrOther = other.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    
    for (int i=0; i < width; i++)
      for (int j=0; j < heigth; j++)
        assertEquals(arrLocal[i][j],arrOther[i][j]);
  }

  /** 
   * Test CORBA oneway calls 
   */
  public void test5() throws Exception {
    ApfelCalculator local = _factory.create(ApfelCalculatorFactory.MODE_LOCAL);
    ApfelCalculator other = _factory.create(ApfelCalculatorFactory.MODE_ONEWAY);
    assertNotNull(other);
    
    int[][] arrLocal = local.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    int[][] arrOther = other.calcMandelbrot(x0, unit, width, y0, unit, heigth, iterations);
    
    for (int i=0; i < width; i++)
      for (int j=0; j < heigth; j++)
        assertEquals(arrLocal[i][j],arrOther[i][j]);
  }
}
